##  Soft Delete
When you archive a fact sheet in SAP LeanIX, by default, the corresponding mapped asset in Collibra is also deleted. However, you can change this behavior by enabling the soft delete option in the configuration.
When the Soft Delete check box is selected, the integration won't delete the asset in Collibra when a fact sheet is archived in SAP LeanIX. Instead, a tag saying deleted-in-leanix is added to the asset in Collibra.
![Enabling Soft Deletion](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e4f0b7a4410148fa1fece3037612d_LowRes.png)
Enabling Soft Deletion
